@@ -10,6 +10,9 @@ SUPPORTED_KINDS = (
     # within them.
     "Namespace",
 
+    # Custom Resources
+    "CustomResourceDefinition",
+
     # Configuration and PVC before Deployments & friends use them.
     "ConfigMap", "Secret", "PersistentVolumeClaim",
 
@@ -17,7 +20,7 @@ SUPPORTED_KINDS = (
     "ClusterRole", "ClusterRoleBinding", "Role", "RoleBinding", "ServiceAccount",
 
     # Define Services before creating Deployments & friends.
-    "Service",
+    "Service", "PodDisruptionBudget",
 
     # Everything that will spawn pods.
     "CronJob", "Deployment", "DaemonSet", "StatefulSet", "HorizontalPodAutoscaler",
@@ -27,6 +30,11 @@ SUPPORTED_KINDS = (
 )
 
 
+# These resource exist outside of namespaces.
+NON_NAMESPACED_KINDS = {
+    "Namespace", "ClusterRole", "ClusterRoleBinding", "CustomResourceDefinition"
+}
+
 # Declare aliases for each resource type. Will be used in command line parsing
 # to save the user some typing and match what `kubectl` would accept. We do not
 # need to worry about capitalisation because `square.parse_commandline_args`
@@ -36,12 +44,14 @@ RESOURCE_ALIASES = {
     "ClusterRoleBinding": {"clusterrolebinding", "clusterrolebindings"},
     "ConfigMap": {"configmap", "cm"},
     "CronJob": {"cronjob", "cj"},
+    "CustomResourceDefinition": {"crd", "customresourcedefinitions"},
     "DaemonSet": {"daemonset", "daemonsets", "ds"},
     "Deployment": {"deployment", "deployments", "deploy"},
     "HorizontalPodAutoscaler": {"hpa"},
     "Ingress": {"ingress", "ingresses", "ing"},
     "Namespace": {"namespace", "namespaces", "ns"},
     "PersistentVolumeClaim": {"persistentVolumeClaim", "persistentvolumeclaims", "pvc"},
+    "PodDisruptionBudget": {"poddisruptionbudget", "pdb"},
     "Role": {"role", "roles"},
     "RoleBinding": {"rolebinding", "rolebindings"},
     "Secret": {"secret", "secrets"},
@@ -53,7 +63,7 @@ RESOURCE_ALIASES = {
 # Sanity check: we must have aliases for every supported resource kind.
 assert set(SUPPORTED_KINDS) == set(RESOURCE_ALIASES.keys())
 
-SUPPORTED_VERSIONS = ("1.9", "1.10", "1.11", "1.12", "1.13", "1.14")
+SUPPORTED_VERSIONS = ("1.9", "1.10", "1.11", "1.12", "1.13", "1.14", "1.15")
 
 Filepath = pathlib.Path
 
