@@ -495,12 +495,14 @@ def urlpath(
             "ClusterRoleBinding": f"apis/rbac.authorization.k8s.io/v1/clusterrolebindings",  # NOQA
             "ConfigMap": f"api/v1/{namespace}/configmaps",
             "CronJob": f"apis/batch/v1beta1/{namespace}/cronjobs",
+            "CustomResourceDefinition": f"apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions",  # NOQA
             "DaemonSet": f"apis/apps/v1/{namespace}/daemonsets",
             "Deployment": f"apis/extensions/v1beta1/{namespace}/deployments",
             "HorizontalPodAutoscaler": f"apis/autoscaling/v1/{namespace}/horizontalpodautoscalers",   # NOQA
             "Ingress": f"apis/extensions/v1beta1/{namespace}/ingresses",
             "Namespace": f"api/v1/namespaces",
             "PersistentVolumeClaim": f"api/v1/{namespace}/persistentvolumeclaims",
+            "PodDisruptionBudget": f"apis/policy/v1beta1/{namespace}/poddisruptionbudgets",  # NOQA
             "Role": f"apis/rbac.authorization.k8s.io/v1/{namespace}/roles",
             "RoleBinding": f"apis/rbac.authorization.k8s.io/v1/{namespace}/rolebindings",
             "Secret": f"api/v1/{namespace}/secrets",
@@ -513,12 +515,14 @@ def urlpath(
             "ClusterRoleBinding": f"apis/rbac.authorization.k8s.io/v1/clusterrolebindings",  # NOQA
             "ConfigMap": f"api/v1/{namespace}/configmaps",
             "CronJob": f"apis/batch/v1beta1/{namespace}/cronjobs",
+            "CustomResourceDefinition": f"apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions",  # NOQA
             "DaemonSet": f"apis/apps/v1/{namespace}/daemonsets",
             "Deployment": f"apis/apps/v1/{namespace}/deployments",
             "HorizontalPodAutoscaler": f"apis/autoscaling/v1/{namespace}/horizontalpodautoscalers",   # NOQA
             "Ingress": f"apis/extensions/v1beta1/{namespace}/ingresses",
             "Namespace": f"api/v1/namespaces",
             "PersistentVolumeClaim": f"api/v1/{namespace}/persistentvolumeclaims",
+            "PodDisruptionBudget": f"apis/policy/v1beta1/{namespace}/poddisruptionbudgets",  # NOQA
             "Role": f"apis/rbac.authorization.k8s.io/v1/{namespace}/roles",
             "RoleBinding": f"apis/rbac.authorization.k8s.io/v1/{namespace}/rolebindings",
             "Secret": f"api/v1/{namespace}/secrets",
@@ -533,12 +537,13 @@ def urlpath(
     resources["1.12"] = resources["1.11"]
     resources["1.13"] = resources["1.11"]
     resources["1.14"] = resources["1.11"]
+    resources["1.15"] = resources["1.11"]
 
     # Look up the resource path and remove duplicate "/" characters (may have
     # slipped in when no namespace was supplied, eg "/api/v1//configmaps").
     path = resources[config.version][kind]
     path = path.replace("//", "/")
-    assert not path.startswith("/")
+    assert not path.startswith("/"), path
 
     # Return the complete resource URL.
     return (f"{config.url}/{path}", False)
